@@ -1,13 +1,13 @@
 import json
+from os import environ
 import re
 
 from logging import getLogger
 from pathlib import Path
+from typing import TYPE_CHECKING
 from uuid import UUID
 from zipfile import ZipFile
 
-from sqlalchemy.orm.session import Session
-from sqlalchemy.sql.expression import delete, insert
 
 from phystool.config import config
 from phystool.helper import as_valid_filename, should_compile
@@ -19,31 +19,26 @@ from phystool.latex import (
     WarningMessage,
 )
 from phystool.tags import Tags
-from phystool.physql.models import PDBRecord, tag_relation
 from phystool.pytex import PyTex
 
+if TYPE_CHECKING:
+    from phystool.physql.models import PDBRecord
+
 
 logger = getLogger(__name__)
 
 
 class PDBFile:
+    _ENVIRONMENT: dict[str, str] = dict()
     UUID_PATTERN = re.compile(
         r"[0-9a-f]{8}-[0-9a-f]{4}-4[0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}"
     )
 
     @classmethod
-    def validate_type(cls, list_of_types: str) -> list[str]:
-        if not list_of_types:
-            return []
-
-        out = list_of_types.split(",")
-        if not set(out).issubset(config.db.VALID_PDB_TYPES):
-            raise ValueError
-
-        return out
-
-    @classmethod
-    def from_record(cls, pdb_record: PDBRecord) -> "PDBFile":
+    def from_record(cls, pdb_record: "PDBRecord") -> "PDBFile":
+        """
+        Converts a PDBRecord into a  PDBFile
+        """
         return PDBFile(
             id=pdb_record.id,
             uuid=pdb_record.uuid,
@@ -57,10 +52,10 @@ class PDBFile:
     @classmethod
     def from_file(cls, key: UUID | Path) -> "PDBFile":
         """
-        Loops over all possible `VALID_PDB_TYPES` and checks if the regex matches the
-        '.tex' file. When a match is found, it parses the `.tex` file to extract the
-        PDB_TYPE, the optional title and all references to other PDBFiles. The tags are
-        read from the related `.json` file if it exists.
+        Loops over all valid pdb_types and checks if the regex matches the '.tex' file.
+        When a match is found, it parses the `.tex` file to extract the PDB_TYPE, the
+        optional title and all references to other PDBFiles. The tags are read from the
+        related `.json` file if it exists.
 
         :returns: PDBFile
         """
@@ -97,7 +92,7 @@ class PDBFile:
             if not match.groups() or match.group(1) is None:
                 title = str(uuid)
             else:
-                title = match.group(1)
+                title = match.group(1)[:50]
 
             return PDBFile(
                 id=0,
@@ -114,17 +109,6 @@ class PDBFile:
                 ),
             )
 
-    @classmethod
-    def remove_files(cls, uuids: list[UUID]) -> None:
-        """
-        Remove all files related to this PDBRecord. If the database is managed by
-        git, the files can be recovered.
-        """
-        for uuid in uuids:
-            for fname in config.db.DB_DIR.glob(f"{uuid}*"):
-                logger.info(f"Removing {fname}")
-                fname.unlink()
-
     def __init__(
         self,
         id: int,
@@ -142,10 +126,7 @@ class PDBFile:
         self.title = title
         self.tags = tags
         self.references = references
-
-    @property
-    def tex_file(self) -> Path:
-        return (config.db.DB_DIR / str(self.uuid)).with_suffix(".tex")
+        self.tex_file = (config.db.DB_DIR / str(self.uuid)).with_suffix(".tex")
 
     def __repr__(self) -> str:
         return f"PDBFile({self.uuid}:{self.title})"
@@ -155,6 +136,9 @@ class PDBFile:
             self.pdb_type.upper()[:3], self.title, str(self.uuid), self.tags
         )
 
+    def __lt__(self, other: "PDBFile") -> bool:
+        return self.tex_file.stat().st_mtime < other.tex_file.stat().st_mtime
+
     def save(self) -> None:
         """Saves the .json file"""
         with self.tex_file.with_suffix(".json").open("w") as jsout:
@@ -170,37 +154,6 @@ class PDBFile:
                 ensure_ascii=False,
             )
 
-    def update_tags(
-        self,
-        session: Session,
-        to_remove: Tags = Tags({}),
-        to_add: Tags = Tags({}),
-    ) -> None:
-        """Update the tags, both in the SQL database and in the .json file"""
-        modified = False
-        if to_delete := (self.tags.as_ids() & to_remove.as_ids()):
-            modified = True
-            session.execute(
-                delete(tag_relation).filter(
-                    tag_relation.c.tag_id.in_(to_delete),
-                    tag_relation.c.pdb_record_id == self.id,
-                )
-            )
-            self.tags -= to_remove
-        if to_create := (to_add.as_ids() - self.tags.as_ids()):
-            modified = True
-            session.execute(
-                insert(tag_relation).values(
-                    [
-                        {"pdb_record_id": self.id, "tag_id": tag_id}
-                        for tag_id in to_create
-                    ]
-                )
-            )
-            self.tags += to_add
-        if modified:
-            self.save()
-
     def create_tmp_tex_file(self) -> Path:
         if self.standalone:
             return self.tex_file
@@ -209,6 +162,12 @@ class PDBFile:
             out.write(config.db.template(self.uuid))
         return tmp_tex_file
 
+    def _get_env(self) -> dict[str, str]:
+        if not self.__class__._ENVIRONMENT:
+            self.__class__._ENVIRONMENT = dict(environ)
+            self.__class__._ENVIRONMENT["TEXINPUTS"] = f":{config.db.PHYSTEX}:"
+        return self.__class__._ENVIRONMENT
+
     def compile(self, verbose: bool) -> None:
         if not should_compile(self.tex_file):
             if verbose:
@@ -219,7 +178,7 @@ class PDBFile:
         tmp_tex_file = self.create_tmp_tex_file()
         pdflatex = PdfLatex(tmp_tex_file)
         try:
-            pdflatex.compile(env=config.db.env())
+            pdflatex.compile(env=self._get_env())
             pdflatex.move_pdf(self.tex_file.with_suffix(".pdf"))
 
             if verbose:
