@@ -82,7 +82,11 @@ class GitFile(ABC):
         out = ""
         for cmd in self._commands():
             tmp = subprocess.run(
-                cmd, capture_output=True, text=True, shell=True, cwd=config.db.DB_DIR
+                cmd,
+                capture_output=True,
+                text=True,
+                shell=True,
+                cwd=config.db.DB_DIR,
             )
             if tmp.returncode == 0:
                 out += tmp.stdout
@@ -108,7 +112,7 @@ class GitPDBFile(GitFile):
                         select(PDBRecord.uuid, PDBRecord.title)
                     )
                 }
-        return self._pdb_record_map[uuid]
+        return self._pdb_record_map.get(uuid, str(uuid))
 
     def add(self, path: Path) -> None:
         if (
@@ -121,14 +125,9 @@ class GitPDBFile(GitFile):
             logger.error(f"Non matching uuids ({path.stem} != {self.uuid})")
             raise PhysGitError(f"{path.stem} != {self.uuid}")
 
+        self.n += 1
         self._files[path.suffix[1:]] = str(path)
-        if not self.n:
-            self.n += 1
-
-        if self.status == self.Status.DELETED:
-            self.title = self.uuid
-        else:
-            self.title = self._get_title(self.uuid)
+        self.title = self._get_title(self.uuid)
 
 
 class GitTexFile(GitFile):
@@ -182,8 +181,8 @@ class PhysGit:
         delta (named git-delta in debian package manager).
         """
         self._repo = Repo(config.db.DB_DIR)
-        self._staged: dict[GitFile.Status, tuple[list[GitFile], int]] = {
-            status: ([], 0) for status in GitFile.Status
+        self._staged: dict[GitFile.Status, list[GitFile]] = {
+            status: [] for status in GitFile.Status
         }
         self._git_map: dict[str, GitFile] = {}
 
@@ -221,22 +220,22 @@ class PhysGit:
     def __getitem__(self, uuid: str) -> GitFile:
         return self._git_map[uuid]
 
-    def __iter__(self) -> Iterator[tuple[str, GitFile]]:
-        return iter(self._git_map.items())
+    def __iter__(self) -> Iterator[GitFile]:
+        return iter(self._git_map.values())
 
     def _get_git_message(self) -> str:
         return "{}\n\n{}".format(
             ", ".join(
                 [
-                    f"{len(list_staged)} ({n}) {status.name}"
-                    for status, (list_staged, n) in self._staged.items()
-                    if n
+                    f"{len(list_staged)} ({sum(git_file.n for git_file in list_staged)}) {status.name}"
+                    for status, list_staged in self._staged.items()
+                    if list_staged
                 ]
             ),
             "\n".join(
-                git_pdb_file.message()
-                for list_staged, _ in self._staged.values()
-                for git_pdb_file in list_staged
+                git_file.message()
+                for list_staged in self._staged.values()
+                for git_file in list_staged
             ),
         )
 
@@ -246,7 +245,7 @@ class PhysGit:
             status: [] for status in GitFile.Status
         }
         maxlen = 0
-        for _, git_pdb_file in self:
+        for git_pdb_file in self:
             by_status[git_pdb_file.status].append(git_pdb_file)
             if len(git_pdb_file.title) > maxlen:
                 maxlen = len(git_pdb_file.title)
@@ -257,19 +256,16 @@ class PhysGit:
                 if terminal_yes_no(
                     f"{git_pdb_file.title: <{maxlen}} -> stage {status.name}?"
                 ):
-                    self.stage(git_pdb_file.uuid)
+                    self.stage(git_pdb_file)
 
-    def stage(self, uuid: str) -> None:
-        git_pdb_file = self[uuid]
-        list_staged, n = self._staged[git_pdb_file.status]
-        list_staged.append(git_pdb_file)
-        self._staged[git_pdb_file.status] = list_staged, n + 1
+    def stage(self, git_pdb_file: GitFile) -> None:
+        self._staged[git_pdb_file.status].append(git_pdb_file)
 
     def commit(self, for_terminal: bool) -> str:
-        if not any([k[0] for k in self._staged.values()]):
+        if not any(self._staged.values()):
             msg = "Nothing was staged, git is left untouched"
             logger.info(msg)
-            return "Nothing was staged, git is left untouched"
+            return msg
 
         git_msg = self._get_git_message()
         logger.info("Review Git actions")
@@ -277,11 +273,11 @@ class PhysGit:
         if for_terminal and not terminal_yes_no("Commit those changes?"):
             return "Commit cancelled by user"
 
-        for git_pdb_file in self._staged[GitFile.Status.UNTRACKED][0]:
+        for git_pdb_file in self._staged[GitFile.Status.UNTRACKED]:
             self._repo.index.add(git_pdb_file.get_files())
-        for git_pdb_file in self._staged[GitFile.Status.MODIFIED][0]:
+        for git_pdb_file in self._staged[GitFile.Status.MODIFIED]:
             self._repo.index.add(git_pdb_file.get_files())
-        for git_pdb_file in self._staged[GitFile.Status.DELETED][0]:
+        for git_pdb_file in self._staged[GitFile.Status.DELETED]:
             self._repo.index.remove(git_pdb_file.get_files())
 
         self._repo.index.commit(git_msg)
