@@ -1,5 +1,6 @@
 from logging import getLogger
 from pathlib import Path
+from typing import cast
 from rapidfuzz.process import extract
 from rapidfuzz.fuzz import QRatio
 from shutil import copyfile
@@ -33,14 +34,14 @@ from PySide6.QtWidgets import (
     QTableWidgetItem,
     QVBoxLayout,
 )
-from sqlalchemy.sql.expression import delete, select
+from sqlalchemy.sql.expression import select
 
 from phystool.config import config
 from phystool.helper import should_compile
 from phystool.pdbfile import PDBFile
 from phystool.physql import physql_db
 from phystool.physql.models import PDBRecord, PDBType
-from phystool.physql.metadata import create_sql_database
+from phystool.physql.metadata import create_sql_database, remove_pdb_files, update_tags
 from phystool.qt.helper import MultipleSelectionWidget
 from phystool.qt.latex import QPdfLatex, CompilationErrorWidget
 from phystool.qt.process import ProcessManager, OpenFileProcess
@@ -52,9 +53,12 @@ logger = getLogger(__name__)
 
 
 class _CategoryTagsWidget(MultipleSelectionWidget):
-    def __init__(self, category: str, left_labels: list[str], right_labels: list[str]):
-        super().__init__(left_labels, right_labels)
-        self.category = category
+    def __init__(self, category_name: str, ltags: Tags, rtags: Tags):
+        super().__init__(
+            ltags.data.get(category_name, []),
+            rtags.data.get(category_name, []),
+        )
+        self.category_name = category_name
 
 
 class _TagSelectionWidget(QDialog):
@@ -69,12 +73,10 @@ class _TagSelectionWidget(QDialog):
         btn_box.accepted.connect(self.accept)
         btn_box.rejected.connect(self.reject)
 
-        available_tags = Tags.TAGS() - current_tags
+        available_tags = Tags.manager.tags - current_tags
         self._widgets = [
-            _CategoryTagsWidget(
-                category, available_tags[category], current_tags[category]
-            )
-            for category, _ in Tags.TAGS()
+            _CategoryTagsWidget(category_name, available_tags, current_tags)
+            for category_name in Tags.manager.tags.data.keys()
         ]
 
         layout = QVBoxLayout(self)
@@ -82,23 +84,30 @@ class _TagSelectionWidget(QDialog):
             layout.addWidget(widget)
         layout.addWidget(btn_box)
 
-    def get_new_tags(self) -> Tags:
-        return Tags(
-            {widget.category: widget.get_right_values() for widget in self._widgets}
-        )
+    def get_new_tags_ids(self) -> set[int]:
+        return {
+            Tags.manager.get_id(widget.category_name, tag_name)
+            for widget in self._widgets
+            for tag_name in widget.get_right_values()
+        }
 
 
 class _TagAction(QAction):
     def __init__(
-        self, category_name: str, tag_name: str, adding: bool, trigger, parent: QObject
+        self,
+        tag_id: int,
+        tag_name: str,
+        adding: bool,
+        trigger,
+        parent: QObject,
     ):
         super().__init__(tag_name, parent)
-        self._tag = Tags({category_name: {tag_name}})
+        self._tag_id = tag_id
         self._adding = adding
         self.triggered.connect(trigger)
 
-    def get_data(self) -> tuple[Tags, bool]:
-        return self._tag, self._adding
+    def get_data(self) -> tuple[int, bool]:
+        return self._tag_id, self._adding
 
 
 class PdbFileListWidget(QTableWidget):
@@ -138,7 +147,7 @@ class PdbFileListWidget(QTableWidget):
         config.DB_NAME = self.sender().text()
         self._filter_widget.save_settings()
         status = config.setup_db()
-        if status in (config.Status.READY, config.Status.MISSING_SQL_FILE):
+        if status == config.Status.READY:
             try:
                 self.consolidate()
                 self._filter_widget.load_settings()
@@ -161,13 +170,13 @@ class PdbFileListWidget(QTableWidget):
             (False, QMenu("Supprimer un tag", context)),
         ]:
             context.addMenu(submenu)
-            for category_name, tags in Tags.TAGS():
+            for category_name, tags in Tags.manager.tags:
                 category_menu = QMenu(category_name, context)
                 submenu.addMenu(category_menu)
                 for tag_name in tags:
                     category_menu.addAction(
                         _TagAction(
-                            category_name=category_name,
+                            tag_id=Tags.manager.get_id(category_name, tag_name),
                             tag_name=tag_name,
                             adding=adding,
                             trigger=self._batch_edit_pdbfile_tags,
@@ -249,23 +258,29 @@ class PdbFileListWidget(QTableWidget):
         dialog = _TagSelectionWidget(pdb_file.tags)
         if dialog.exec():
             with physql_db() as session:
-                pdb_file.update_tags(
+                update_tags(
+                    pdb_file,
                     session,
-                    to_add=dialog.get_new_tags(),
-                    to_remove=pdb_file.tags,
+                    to_remove_ids=pdb_file.tags.as_ids(),
+                    to_add_ids=dialog.get_new_tags_ids(),
                 )
                 self.setItem(row, 2, QTableWidgetItem(str(pdb_file.tags)))
 
     @Slot()
     def _batch_edit_pdbfile_tags(self) -> None:
         pdb_file_map = self._get_selected_pdb_file_map()
-        tags, adding = self.sender().get_data()
+        tag_id, adding = cast(_TagAction, self.sender()).get_data()
         with physql_db() as session:
             for row, pdb_file in pdb_file_map.items():
                 if adding:
-                    pdb_file.update_tags(session, to_add=tags)
+                    update_tags(
+                        pdb_file, session, to_add_ids={tag_id}, to_remove_ids=set()
+                    )
                 else:
-                    pdb_file.update_tags(session, to_remove=tags)
+                    update_tags(
+                        pdb_file, session, to_add_ids=set(), to_remove_ids={tag_id}
+                    )
+
                 self.setItem(row, 2, QTableWidgetItem(str(pdb_file.tags)))
 
     @Slot()
@@ -299,6 +314,7 @@ class PdbFileListWidget(QTableWidget):
             dialog.setValue(i)
 
         self._filter_widget.filter_pdb_files()
+        self._filter_widget.update_filter_tags()
 
     @Slot()
     def delete_pdb_file(self) -> None:
@@ -321,10 +337,7 @@ class PdbFileListWidget(QTableWidget):
             )
             button = QMessageBox.question(self, title, msg)
             if button == QMessageBox.StandardButton.Yes:
-                uuids = [pdb_file.uuid for pdb_file in pdb_files]
-                with physql_db() as session:
-                    session.execute(delete(PDBRecord).filter(PDBRecord.uuid.in_(uuids)))
-                    PDBFile.remove_files(uuids)
+                remove_pdb_files([pdb_file.uuid for pdb_file in pdb_files])
                 self._filter_widget.filter_pdb_files()
                 msg = "Les fichiers sélectionnés ont bien été supprimés"
             elif button == QMessageBox.StandardButton.No:
