@@ -12,10 +12,7 @@ logger = getLogger(__name__)
 class PdfWidget(QWebEngineView):
     def __init__(self) -> None:
         super().__init__()
-        self.settings().setAttribute(
-            self.settings().WebAttribute.PluginsEnabled,
-            True
-        )
+        self.settings().setAttribute(self.settings().WebAttribute.PluginsEnabled, True)
 
     @Slot(PDBFile)
     def display(self, pdb_file: PDBFile) -> None:
